# -*- coding: utf-8 -*-

def rusngettext(number, forms):
    """Returns singular or plural text form of number."""
    if isinstance(forms, str):
        return forms

    first, second, third = forms

    result_from_100 = number % 100
    if result_from_100 < 10 or result_from_100 > 20:
        result_from_10 = number % 10
        if result_from_10 == 1:
            return first

        if 1 < result_from_10 < 5:
            print('wtf??')
            return second

    return third



from setuptools import setup


with open('README.md', 'r') as f:
    readme = f.read()


if __name__ == '__main__':
    setup(
        name='rusn',
        version='1.0.1',
        author='Dmitriy Pleshevskiy',
        author_email='dmitriy@ideascup.me',
        description='Small library for getting russian text with singular and plural forms',
        long_description=readme,
        long_description_content_type='text/markdown',
        package_data={'': ['LICENSE', 'README.md']},
        include_package_data=True,
        license='MIT',
        packages=['rusn']
    )
